diff src/gui.c @ 1695:0dbc46d14443 v7.2b.028

updated for version 7.2b-028
author vimboss
date Wed, 06 Aug 2008 12:37:44 +0000
parents 0b796e045c42
children f10fe14748e2
line wrap: on
line diff
--- a/src/gui.c
+++ b/src/gui.c
@@ -901,9 +901,10 @@ gui_update_cursor(force, clear_selection
     int		attr;
     attrentry_T *aep = NULL;
 
-    /* Don't update the cursor when halfway busy scrolling.
-     * ScreenLines[] isn't valid then. */
-    if (!can_update_cursor)
+    /* Don't update the cursor when halfway busy scrolling or the screen size
+     * doesn't match 'columns' and 'lines.  ScreenLines[] isn't valid then. */
+    if (!can_update_cursor || screen_Columns != gui.num_cols
+					       || screen_Rows != gui.num_rows)
 	return;
 
     gui_check_pos();